@@ -103,7 +103,7 @@ sub _process_result {
     $self->tx($tx);    # save latest transaction
 
     my $tx_res = $tx->res;
-    my $log    = $self->ua->app->log;
+    my $log    = $self->ua->log;
     if ( $log->is_debug ) {
         $log->debug( 'TX BODY: [' . $tx_res->body . ']' );
     }
@@ -322,7 +322,6 @@ is executed correctly.
     my $client = MojoX::JSON::RPC::Client->new;
     my $url    = 'http://www.example.com/jsonrpc/API';
     my $callobj = {
-        id      => 1,
         method  => 'sum',
         params  => [ 17, 25 ]
     };
